diff --git a/src/backend/access/transam/xlog.c b/src/backend/access/transam/xlog.c
--- a/src/backend/access/transam/xlog.c
+++ b/src/backend/access/transam/xlog.c
@@ -6083,7 +6083,7 @@ StartupXLOG(void)
 		ereport(LOG,
 				(errmsg("database system was shut down in recovery at %s",
 						str_time(ControlFile->time))));
-	else if (ControlFile->state == DB_SHUTDOWNING)
+	else if (ControlFile->state == DB_SHUTTINGDOWN)
 		ereport(LOG,
 				(errmsg("database system shutdown was interrupted; last known up at %s",
 						str_time(ControlFile->time))));
@@ -8398,7 +8398,7 @@ CreateCheckPoint(int flags)
 	if (shutdown)
 	{
 		LWLockAcquire(ControlFileLock, LW_EXCLUSIVE);
-		ControlFile->state = DB_SHUTDOWNING;
+		ControlFile->state = DB_SHUTTINGDOWN;
 		ControlFile->time = (pg_time_t) time(NULL);
 		UpdateControlFile();
 		LWLockRelease(ControlFileLock);
diff --git a/src/backend/executor/nodeLockRows.c b/src/backend/executor/nodeLockRows.c
--- a/src/backend/executor/nodeLockRows.c
+++ b/src/backend/executor/nodeLockRows.c
@@ -349,7 +349,7 @@ ExecInitLockRows(LockRows *node, EState 
 {
 	LockRowsState *lrstate;
 	Plan	   *outerPlan = outerPlan(node);
-	List	   *epq_arowmarks;
+	List	   *epq_arowMarks;
 	ListCell   *lc;
 
 	/* check for unsupported flags */
@@ -398,7 +398,7 @@ ExecInitLockRows(LockRows *node, EState 
 	 * built the global list of ExecRowMarks.)
 	 */
 	lrstate->lr_arowMarks = NIL;
-	epq_arowmarks = NIL;
+	epq_arowMarks = NIL;
 	foreach(lc, node->rowMarks)
 	{
 		PlanRowMark *rc = castNode(PlanRowMark, lfirst(lc));
@@ -425,12 +425,12 @@ ExecInitLockRows(LockRows *node, EState 
 		if (RowMarkRequiresRowShareLock(erm->markType))
 			lrstate->lr_arowMarks = lappend(lrstate->lr_arowMarks, aerm);
 		else
-			epq_arowmarks = lappend(epq_arowmarks, aerm);
+			epq_arowMarks = lappend(epq_arowMarks, aerm);
 	}
 
 	/* Now we have the info needed to set up EPQ state */
 	EvalPlanQualInit(&lrstate->lr_epqstate, estate,
-					 outerPlan, epq_arowmarks, node->epqParam);
+					 outerPlan, epq_arowMarks, node->epqParam);
 
 	return lrstate;
 }
diff --git a/src/backend/executor/nodeModifyTable.c b/src/backend/executor/nodeModifyTable.c
--- a/src/backend/executor/nodeModifyTable.c
+++ b/src/backend/executor/nodeModifyTable.c
@@ -1471,7 +1471,7 @@ ExecModifyTable(ModifyTableState *node)
 				junkfilter = resultRelInfo->ri_junkFilter;
 				estate->es_result_relation_info = resultRelInfo;
 				EvalPlanQualSetPlan(&node->mt_epqstate, subplanstate->plan,
-									node->mt_arowmarks[node->mt_whichplan]);
+									node->mt_arowMarks[node->mt_whichplan]);
 				continue;
 			}
 			else
@@ -1653,7 +1653,7 @@ ExecInitModifyTable(ModifyTable *node, E
 
 	mtstate->mt_plans = (PlanState **) palloc0(sizeof(PlanState *) * nplans);
 	mtstate->resultRelInfo = estate->es_result_relations + node->resultRelIndex;
-	mtstate->mt_arowmarks = (List **) palloc0(sizeof(List *) * nplans);
+	mtstate->mt_arowMarks = (List **) palloc0(sizeof(List *) * nplans);
 	mtstate->mt_nplans = nplans;
 	mtstate->mt_onconflict = node->onConflictAction;
 	mtstate->mt_arbiterindexes = node->arbiterIndexes;
@@ -1975,7 +1975,7 @@ ExecInitModifyTable(ModifyTable *node, E
 
 			subplan = mtstate->mt_plans[i]->plan;
 			aerm = ExecBuildAuxRowMark(erm, subplan->targetlist);
-			mtstate->mt_arowmarks[i] = lappend(mtstate->mt_arowmarks[i], aerm);
+			mtstate->mt_arowMarks[i] = lappend(mtstate->mt_arowMarks[i], aerm);
 		}
 	}
 
@@ -1983,7 +1983,7 @@ ExecInitModifyTable(ModifyTable *node, E
 	mtstate->mt_whichplan = 0;
 	subplan = (Plan *) linitial(node->plans);
 	EvalPlanQualSetPlan(&mtstate->mt_epqstate, subplan,
-						mtstate->mt_arowmarks[0]);
+						mtstate->mt_arowMarks[0]);
 
 	/*
 	 * Initialize the junk filter(s) if needed.  INSERT queries need a filter
diff --git a/src/bin/pg_controldata/pg_controldata.c b/src/bin/pg_controldata/pg_controldata.c
--- a/src/bin/pg_controldata/pg_controldata.c
+++ b/src/bin/pg_controldata/pg_controldata.c
@@ -54,7 +54,7 @@ dbState(DBState state)
 			return _("shut down");
 		case DB_SHUTDOWNED_IN_RECOVERY:
 			return _("shut down in recovery");
-		case DB_SHUTDOWNING:
+		case DB_SHUTTINGDOWN:
 			return _("shutting down");
 		case DB_IN_CRASH_RECOVERY:
 			return _("in crash recovery");
diff --git a/src/include/catalog/pg_control.h b/src/include/catalog/pg_control.h
--- a/src/include/catalog/pg_control.h
+++ b/src/include/catalog/pg_control.h
@@ -84,7 +84,7 @@ typedef enum DBState
 	DB_STARTUP = 0,
 	DB_SHUTDOWNED,
 	DB_SHUTDOWNED_IN_RECOVERY,
-	DB_SHUTDOWNING,
+	DB_SHUTTINGDOWN,
 	DB_IN_CRASH_RECOVERY,
 	DB_IN_ARCHIVE_RECOVERY,
 	DB_IN_PRODUCTION
diff --git a/src/include/lib/simplehash.h b/src/include/lib/simplehash.h
--- a/src/include/lib/simplehash.h
+++ b/src/include/lib/simplehash.h
@@ -854,7 +854,7 @@ SH_STAT(SH_TYPE *tb)
 #undef SH_STATUS
 #undef SH_STATUS_EMPTY
 #undef SH_STATUS_IN_USE
-#undef SH_ITERTOR
+#undef SH_ITERATOR
 
 /* external function names */
 #undef SH_CREATE
diff --git a/src/include/nodes/execnodes.h b/src/include/nodes/execnodes.h
--- a/src/include/nodes/execnodes.h
+++ b/src/include/nodes/execnodes.h
@@ -1150,7 +1150,7 @@ typedef struct ModifyTableState
 	int			mt_nplans;		/* number of plans in the array */
 	int			mt_whichplan;	/* which one is being executed (0..n-1) */
 	ResultRelInfo *resultRelInfo;		/* per-subplan target relations */
-	List	  **mt_arowmarks;	/* per-subplan ExecAuxRowMark lists */
+	List	  **mt_arowMarks;	/* per-subplan ExecAuxRowMark lists */
 	EPQState	mt_epqstate;	/* for evaluating EvalPlanQual rechecks */
 	bool		fireBSTriggers; /* do we need to fire stmt triggers? */
 	OnConflictAction mt_onconflict;		/* ON CONFLICT type */
